import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class CodeView extends StatefulWidget {
  final double? maxWidth;
  final double? maxHeight;
  final Widget? run;

  final String code;

  const CodeView({
    Key? key,
    this.maxWidth,
    this.maxHeight,
    this.run,
    required this.code,
  }) : super(key: key);

  @override
  State<CodeView> createState() => _CodeViewState();
}

class _CodeViewState extends State<CodeView> {
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Container(
        constraints: BoxConstraints(
            maxWidth: widget.maxWidth ?? 800,
            maxHeight: widget.maxHeight ?? 300),
        padding: const EdgeInsets.all(10),
        decoration: BoxDecoration(
          color: Colors.grey.withOpacity(.1),
          borderRadius: BorderRadius.circular(25),
        ),
        child: Stack(
          children: [
            Positioned(
              top: 0,
              right: 0,
              child: IconButton(
                icon: const Icon(Icons.copy),
                onPressed: () {
                  Clipboard.setData(ClipboardData(text: widget.code));
                  ScaffoldMessenger.of(context).hideCurrentSnackBar();

                  ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
                      behavior: SnackBarBehavior.floating,
                      content: Text("Copied")));
                },
              ),
            ),
            Positioned(
              bottom: 0,
              right: 0,
              child: Text(
                "Length: " + widget.code.length.toString(),
              ),
            ),
            Center(
              child: SingleChildScrollView(
                  padding: const EdgeInsets.all(10),
                  child: SelectableText(
                    widget.code,
                    style: TextStyle(color: Colors.black),
                  )),
            ),
          ],
        ),
      ),
    );
  }
}
